//----------------------------------------------------------------------
//EASTRISING TECHNOLOGY CO,.LTD.//
// Module    : ER-OLEDM1.92-1  1.92"  128*160
// Lanuage   : C51 Code
// Create    : JAVEN
// Date      : 2021-12-30
// Drive IC  : SH1108
// INTERFACE : I2C
// MCU 	 : STC89LE52RC
// VDD		 : 3.3V    
//----------------------------------------------------------------------


#include <AT89X52.H>
#include <intrins.h>

#define uint unsigned int
#define uchar unsigned char

//LCD IO		
#define SDA                  P1_1
#define SCL                  P1_0

#define RST                  P3_4

#define Write_Address 0x78/*slave addresses with write*/
#define Read_Address 0x79/*slave addresses with read*/

//KEY Adjust contrast
sbit key_add=P0^1;
sbit key_dec=P0^2;
sbit pause=P3^2;
bit log=0;
uchar Contrast=0xd0;

//Resolution
uchar	 SIZE;
#define Max_Column	128
#define Max_Row		160



void Delay(uint n);
void delay_ms(uint Delay);
void display_Contrast(uchar number);
void adj_Contrast(void);
	
void Set_Contrast_Control_Register(unsigned char mod);
void Set_Column_Address(unsigned char add);
void Set_Page_Address(unsigned char add);
void Write_Data(unsigned char dat);
void Write_Instruction(unsigned char cmd);
void Initial(void);	
void ClearScreen(void);
void ShowChar(unsigned char x,unsigned char y,unsigned char chr);
void ShowNum(unsigned char x,unsigned char y,unsigned int  num,unsigned char len,unsigned char size2);
void ShowString(unsigned char x,unsigned char y, unsigned char *p);	 
void Set_Pos(unsigned char x, unsigned char y);
void ShowCHinese(unsigned char x,unsigned char y,unsigned char no);
void DrawBMP(unsigned char x0, unsigned char y0,unsigned char x1, unsigned char y1,unsigned char BMP[]);												 
void Show_line_dot();
void Show(unsigned char d1,unsigned char d2);


void SentByte(unsigned char Byte);
void Check_Ack(void);//Acknowledge
void Stop(void);
void Start(void);
void Send_ACK(void);
unsigned char ReceiveByte(void);



//ASCII
//ASCIIַ
//С:6*8
/************************************6*8ĵ************************************/
const unsigned char code F6x8[][6] =		
{
0x00, 0x00, 0x00, 0x00, 0x00, 0x00,// sp
0x00, 0x00, 0x00, 0x2f, 0x00, 0x00,// !
0x00, 0x00, 0x07, 0x00, 0x07, 0x00,// "
0x00, 0x14, 0x7f, 0x14, 0x7f, 0x14,// #
0x00, 0x24, 0x2a, 0x7f, 0x2a, 0x12,// $
0x00, 0x62, 0x64, 0x08, 0x13, 0x23,// %
0x00, 0x36, 0x49, 0x55, 0x22, 0x50,// &
0x00, 0x00, 0x05, 0x03, 0x00, 0x00,// '
0x00, 0x00, 0x1c, 0x22, 0x41, 0x00,// (
0x00, 0x00, 0x41, 0x22, 0x1c, 0x00,// )
0x00, 0x14, 0x08, 0x3E, 0x08, 0x14,// *
0x00, 0x08, 0x08, 0x3E, 0x08, 0x08,// +
0x00, 0x00, 0x00, 0xA0, 0x60, 0x00,// ,
0x00, 0x08, 0x08, 0x08, 0x08, 0x08,// -
0x00, 0x00, 0x60, 0x60, 0x00, 0x00,// .
0x00, 0x20, 0x10, 0x08, 0x04, 0x02,// /
0x00, 0x3E, 0x51, 0x49, 0x45, 0x3E,// 0
0x00, 0x00, 0x42, 0x7F, 0x40, 0x00,// 1
0x00, 0x42, 0x61, 0x51, 0x49, 0x46,// 2
0x00, 0x21, 0x41, 0x45, 0x4B, 0x31,// 3
0x00, 0x18, 0x14, 0x12, 0x7F, 0x10,// 4
0x00, 0x27, 0x45, 0x45, 0x45, 0x39,// 5
0x00, 0x3C, 0x4A, 0x49, 0x49, 0x30,// 6
0x00, 0x01, 0x71, 0x09, 0x05, 0x03,// 7
0x00, 0x36, 0x49, 0x49, 0x49, 0x36,// 8
0x00, 0x06, 0x49, 0x49, 0x29, 0x1E,// 9
0x00, 0x00, 0x36, 0x36, 0x00, 0x00,// :
0x00, 0x00, 0x56, 0x36, 0x00, 0x00,// ;
0x00, 0x08, 0x14, 0x22, 0x41, 0x00,// <
0x00, 0x14, 0x14, 0x14, 0x14, 0x14,// =
0x00, 0x00, 0x41, 0x22, 0x14, 0x08,// >
0x00, 0x02, 0x01, 0x51, 0x09, 0x06,// ?
0x00, 0x32, 0x49, 0x59, 0x51, 0x3E,// @
0x00, 0x7C, 0x12, 0x11, 0x12, 0x7C,// A
0x00, 0x7F, 0x49, 0x49, 0x49, 0x36,// B
0x00, 0x3E, 0x41, 0x41, 0x41, 0x22,// C
0x00, 0x7F, 0x41, 0x41, 0x22, 0x1C,// D
0x00, 0x7F, 0x49, 0x49, 0x49, 0x41,// E
0x00, 0x7F, 0x09, 0x09, 0x09, 0x01,// F
0x00, 0x3E, 0x41, 0x49, 0x49, 0x7A,// G
0x00, 0x7F, 0x08, 0x08, 0x08, 0x7F,// H
0x00, 0x00, 0x41, 0x7F, 0x41, 0x00,// I
0x00, 0x20, 0x40, 0x41, 0x3F, 0x01,// J
0x00, 0x7F, 0x08, 0x14, 0x22, 0x41,// K
0x00, 0x7F, 0x40, 0x40, 0x40, 0x40,// L
0x00, 0x7F, 0x02, 0x0C, 0x02, 0x7F,// M
0x00, 0x7F, 0x04, 0x08, 0x10, 0x7F,// N
0x00, 0x3E, 0x41, 0x41, 0x41, 0x3E,// O
0x00, 0x7F, 0x09, 0x09, 0x09, 0x06,// P
0x00, 0x3E, 0x41, 0x51, 0x21, 0x5E,// Q
0x00, 0x7F, 0x09, 0x19, 0x29, 0x46,// R
0x00, 0x46, 0x49, 0x49, 0x49, 0x31,// S
0x00, 0x01, 0x01, 0x7F, 0x01, 0x01,// T
0x00, 0x3F, 0x40, 0x40, 0x40, 0x3F,// U
0x00, 0x1F, 0x20, 0x40, 0x20, 0x1F,// V
0x00, 0x3F, 0x40, 0x38, 0x40, 0x3F,// W
0x00, 0x63, 0x14, 0x08, 0x14, 0x63,// X
0x00, 0x07, 0x08, 0x70, 0x08, 0x07,// Y
0x00, 0x61, 0x51, 0x49, 0x45, 0x43,// Z
0x00, 0x00, 0x7F, 0x41, 0x41, 0x00,// [
0x00, 0x55, 0x2A, 0x55, 0x2A, 0x55,// 55
0x00, 0x00, 0x41, 0x41, 0x7F, 0x00,// ]
0x00, 0x04, 0x02, 0x01, 0x02, 0x04,// ^
0x00, 0x40, 0x40, 0x40, 0x40, 0x40,// _
0x00, 0x00, 0x01, 0x02, 0x04, 0x00,// '
0x00, 0x20, 0x54, 0x54, 0x54, 0x78,// a
0x00, 0x7F, 0x48, 0x44, 0x44, 0x38,// b
0x00, 0x38, 0x44, 0x44, 0x44, 0x20,// c
0x00, 0x38, 0x44, 0x44, 0x48, 0x7F,// d
0x00, 0x38, 0x54, 0x54, 0x54, 0x18,// e
0x00, 0x08, 0x7E, 0x09, 0x01, 0x02,// f
0x00, 0x18, 0xA4, 0xA4, 0xA4, 0x7C,// g
0x00, 0x7F, 0x08, 0x04, 0x04, 0x78,// h
0x00, 0x00, 0x44, 0x7D, 0x40, 0x00,// i
0x00, 0x40, 0x80, 0x84, 0x7D, 0x00,// j
0x00, 0x7F, 0x10, 0x28, 0x44, 0x00,// k
0x00, 0x00, 0x41, 0x7F, 0x40, 0x00,// l
0x00, 0x7C, 0x04, 0x18, 0x04, 0x78,// m
0x00, 0x7C, 0x08, 0x04, 0x04, 0x78,// n
0x00, 0x38, 0x44, 0x44, 0x44, 0x38,// o
0x00, 0xFC, 0x24, 0x24, 0x24, 0x18,// p
0x00, 0x18, 0x24, 0x24, 0x18, 0xFC,// q
0x00, 0x7C, 0x08, 0x04, 0x04, 0x08,// r
0x00, 0x48, 0x54, 0x54, 0x54, 0x20,// s
0x00, 0x04, 0x3F, 0x44, 0x40, 0x20,// t
0x00, 0x3C, 0x40, 0x40, 0x20, 0x7C,// u
0x00, 0x1C, 0x20, 0x40, 0x20, 0x1C,// v
0x00, 0x3C, 0x40, 0x30, 0x40, 0x3C,// w
0x00, 0x44, 0x28, 0x10, 0x28, 0x44,// x
0x00, 0x1C, 0xA0, 0xA0, 0xA0, 0x7C,// y
0x00, 0x44, 0x64, 0x54, 0x4C, 0x44,// z
0x14, 0x14, 0x14, 0x14, 0x14, 0x14,// horiz lines
};
/****************************************8*16ĵ************************************/
const unsigned char code F8X16[]=	  
{
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,// 0
  0x00,0x00,0x00,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x33,0x30,0x00,0x00,0x00,//! 1
  0x00,0x10,0x0C,0x06,0x10,0x0C,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,//" 2
  0x40,0xC0,0x78,0x40,0xC0,0x78,0x40,0x00,0x04,0x3F,0x04,0x04,0x3F,0x04,0x04,0x00,//# 3
  0x00,0x70,0x88,0xFC,0x08,0x30,0x00,0x00,0x00,0x18,0x20,0xFF,0x21,0x1E,0x00,0x00,//$ 4
  0xF0,0x08,0xF0,0x00,0xE0,0x18,0x00,0x00,0x00,0x21,0x1C,0x03,0x1E,0x21,0x1E,0x00,//% 5
  0x00,0xF0,0x08,0x88,0x70,0x00,0x00,0x00,0x1E,0x21,0x23,0x24,0x19,0x27,0x21,0x10,//& 6
  0x10,0x16,0x0E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,//' 7
  0x00,0x00,0x00,0xE0,0x18,0x04,0x02,0x00,0x00,0x00,0x00,0x07,0x18,0x20,0x40,0x00,//( 8
  0x00,0x02,0x04,0x18,0xE0,0x00,0x00,0x00,0x00,0x40,0x20,0x18,0x07,0x00,0x00,0x00,//) 9
  0x40,0x40,0x80,0xF0,0x80,0x40,0x40,0x00,0x02,0x02,0x01,0x0F,0x01,0x02,0x02,0x00,//* 10
  0x00,0x00,0x00,0xF0,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x1F,0x01,0x01,0x01,0x00,//+ 11
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xB0,0x70,0x00,0x00,0x00,0x00,0x00,//, 12
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,//- 13
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x00,0x00,0x00,0x00,//. 14
  0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x04,0x00,0x60,0x18,0x06,0x01,0x00,0x00,0x00,/// 15
  0x00,0xE0,0x10,0x08,0x08,0x10,0xE0,0x00,0x00,0x0F,0x10,0x20,0x20,0x10,0x0F,0x00,//0 16
  0x00,0x10,0x10,0xF8,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x3F,0x20,0x20,0x00,0x00,//1 17
  0x00,0x70,0x08,0x08,0x08,0x88,0x70,0x00,0x00,0x30,0x28,0x24,0x22,0x21,0x30,0x00,//2 18
  0x00,0x30,0x08,0x88,0x88,0x48,0x30,0x00,0x00,0x18,0x20,0x20,0x20,0x11,0x0E,0x00,//3 19
  0x00,0x00,0xC0,0x20,0x10,0xF8,0x00,0x00,0x00,0x07,0x04,0x24,0x24,0x3F,0x24,0x00,//4 20
  0x00,0xF8,0x08,0x88,0x88,0x08,0x08,0x00,0x00,0x19,0x21,0x20,0x20,0x11,0x0E,0x00,//5 21
  0x00,0xE0,0x10,0x88,0x88,0x18,0x00,0x00,0x00,0x0F,0x11,0x20,0x20,0x11,0x0E,0x00,//6 22
  0x00,0x38,0x08,0x08,0xC8,0x38,0x08,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,//7 23
  0x00,0x70,0x88,0x08,0x08,0x88,0x70,0x00,0x00,0x1C,0x22,0x21,0x21,0x22,0x1C,0x00,//8 24
  0x00,0xE0,0x10,0x08,0x08,0x10,0xE0,0x00,0x00,0x00,0x31,0x22,0x22,0x11,0x0F,0x00,//9 25
  0x00,0x00,0x00,0xC0,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x00,0x00,//: 26
  0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x00,0x00,//; 27
  0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x00,//< 28
  0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,//= 29
  0x00,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x20,0x10,0x08,0x04,0x02,0x01,0x00,//> 30
  0x00,0x70,0x48,0x08,0x08,0x08,0xF0,0x00,0x00,0x00,0x00,0x30,0x36,0x01,0x00,0x00,//? 31
  0xC0,0x30,0xC8,0x28,0xE8,0x10,0xE0,0x00,0x07,0x18,0x27,0x24,0x23,0x14,0x0B,0x00,//@ 32
  0x00,0x00,0xC0,0x38,0xE0,0x00,0x00,0x00,0x20,0x3C,0x23,0x02,0x02,0x27,0x38,0x20,//A 33
  0x08,0xF8,0x88,0x88,0x88,0x70,0x00,0x00,0x20,0x3F,0x20,0x20,0x20,0x11,0x0E,0x00,//B 34
  0xC0,0x30,0x08,0x08,0x08,0x08,0x38,0x00,0x07,0x18,0x20,0x20,0x20,0x10,0x08,0x00,//C 35
  0x08,0xF8,0x08,0x08,0x08,0x10,0xE0,0x00,0x20,0x3F,0x20,0x20,0x20,0x10,0x0F,0x00,//D 36
  0x08,0xF8,0x88,0x88,0xE8,0x08,0x10,0x00,0x20,0x3F,0x20,0x20,0x23,0x20,0x18,0x00,//E 37
  0x08,0xF8,0x88,0x88,0xE8,0x08,0x10,0x00,0x20,0x3F,0x20,0x00,0x03,0x00,0x00,0x00,//F 38
  0xC0,0x30,0x08,0x08,0x08,0x38,0x00,0x00,0x07,0x18,0x20,0x20,0x22,0x1E,0x02,0x00,//G 39
  0x08,0xF8,0x08,0x00,0x00,0x08,0xF8,0x08,0x20,0x3F,0x21,0x01,0x01,0x21,0x3F,0x20,//H 40
  0x00,0x08,0x08,0xF8,0x08,0x08,0x00,0x00,0x00,0x20,0x20,0x3F,0x20,0x20,0x00,0x00,//I 41
  0x00,0x00,0x08,0x08,0xF8,0x08,0x08,0x00,0xC0,0x80,0x80,0x80,0x7F,0x00,0x00,0x00,//J 42
  0x08,0xF8,0x88,0xC0,0x28,0x18,0x08,0x00,0x20,0x3F,0x20,0x01,0x26,0x38,0x20,0x00,//K 43
  0x08,0xF8,0x08,0x00,0x00,0x00,0x00,0x00,0x20,0x3F,0x20,0x20,0x20,0x20,0x30,0x00,//L 44
  0x08,0xF8,0xF8,0x00,0xF8,0xF8,0x08,0x00,0x20,0x3F,0x00,0x3F,0x00,0x3F,0x20,0x00,//M 45
  0x08,0xF8,0x30,0xC0,0x00,0x08,0xF8,0x08,0x20,0x3F,0x20,0x00,0x07,0x18,0x3F,0x00,//N 46
  0xE0,0x10,0x08,0x08,0x08,0x10,0xE0,0x00,0x0F,0x10,0x20,0x20,0x20,0x10,0x0F,0x00,//O 47
  0x08,0xF8,0x08,0x08,0x08,0x08,0xF0,0x00,0x20,0x3F,0x21,0x01,0x01,0x01,0x00,0x00,//P 48
  0xE0,0x10,0x08,0x08,0x08,0x10,0xE0,0x00,0x0F,0x18,0x24,0x24,0x38,0x50,0x4F,0x00,//Q 49
  0x08,0xF8,0x88,0x88,0x88,0x88,0x70,0x00,0x20,0x3F,0x20,0x00,0x03,0x0C,0x30,0x20,//R 50
  0x00,0x70,0x88,0x08,0x08,0x08,0x38,0x00,0x00,0x38,0x20,0x21,0x21,0x22,0x1C,0x00,//S 51
  0x18,0x08,0x08,0xF8,0x08,0x08,0x18,0x00,0x00,0x00,0x20,0x3F,0x20,0x00,0x00,0x00,//T 52
  0x08,0xF8,0x08,0x00,0x00,0x08,0xF8,0x08,0x00,0x1F,0x20,0x20,0x20,0x20,0x1F,0x00,//U 53
  0x08,0x78,0x88,0x00,0x00,0xC8,0x38,0x08,0x00,0x00,0x07,0x38,0x0E,0x01,0x00,0x00,//V 54
  0xF8,0x08,0x00,0xF8,0x00,0x08,0xF8,0x00,0x03,0x3C,0x07,0x00,0x07,0x3C,0x03,0x00,//W 55
  0x08,0x18,0x68,0x80,0x80,0x68,0x18,0x08,0x20,0x30,0x2C,0x03,0x03,0x2C,0x30,0x20,//X 56
  0x08,0x38,0xC8,0x00,0xC8,0x38,0x08,0x00,0x00,0x00,0x20,0x3F,0x20,0x00,0x00,0x00,//Y 57
  0x10,0x08,0x08,0x08,0xC8,0x38,0x08,0x00,0x20,0x38,0x26,0x21,0x20,0x20,0x18,0x00,//Z 58
  0x00,0x00,0x00,0xFE,0x02,0x02,0x02,0x00,0x00,0x00,0x00,0x7F,0x40,0x40,0x40,0x00,//[ 59
  0x00,0x0C,0x30,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x38,0xC0,0x00,//\ 60
  0x00,0x02,0x02,0x02,0xFE,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x7F,0x00,0x00,0x00,//] 61
  0x00,0x00,0x04,0x02,0x02,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,//^ 62
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,//_ 63
  0x00,0x02,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,//` 64
  0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x19,0x24,0x22,0x22,0x22,0x3F,0x20,//a 65
  0x08,0xF8,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x3F,0x11,0x20,0x20,0x11,0x0E,0x00,//b 66
  0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x0E,0x11,0x20,0x20,0x20,0x11,0x00,//c 67
  0x00,0x00,0x00,0x80,0x80,0x88,0xF8,0x00,0x00,0x0E,0x11,0x20,0x20,0x10,0x3F,0x20,//d 68
  0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x1F,0x22,0x22,0x22,0x22,0x13,0x00,//e 69
  0x00,0x80,0x80,0xF0,0x88,0x88,0x88,0x18,0x00,0x20,0x20,0x3F,0x20,0x20,0x00,0x00,//f 70
  0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x6B,0x94,0x94,0x94,0x93,0x60,0x00,//g 71
  0x08,0xF8,0x00,0x80,0x80,0x80,0x00,0x00,0x20,0x3F,0x21,0x00,0x00,0x20,0x3F,0x20,//h 72
  0x00,0x80,0x98,0x98,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x3F,0x20,0x20,0x00,0x00,//i 73
  0x00,0x00,0x00,0x80,0x98,0x98,0x00,0x00,0x00,0xC0,0x80,0x80,0x80,0x7F,0x00,0x00,//j 74
  0x08,0xF8,0x00,0x00,0x80,0x80,0x80,0x00,0x20,0x3F,0x24,0x02,0x2D,0x30,0x20,0x00,//k 75
  0x00,0x08,0x08,0xF8,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x3F,0x20,0x20,0x00,0x00,//l 76
  0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x20,0x3F,0x20,0x00,0x3F,0x20,0x00,0x3F,//m 77
  0x80,0x80,0x00,0x80,0x80,0x80,0x00,0x00,0x20,0x3F,0x21,0x00,0x00,0x20,0x3F,0x20,//n 78
  0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x1F,0x20,0x20,0x20,0x20,0x1F,0x00,//o 79
  0x80,0x80,0x00,0x80,0x80,0x00,0x00,0x00,0x80,0xFF,0xA1,0x20,0x20,0x11,0x0E,0x00,//p 80
  0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x0E,0x11,0x20,0x20,0xA0,0xFF,0x80,//q 81
  0x80,0x80,0x80,0x00,0x80,0x80,0x80,0x00,0x20,0x20,0x3F,0x21,0x20,0x00,0x01,0x00,//r 82
  0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x33,0x24,0x24,0x24,0x24,0x19,0x00,//s 83
  0x00,0x80,0x80,0xE0,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x1F,0x20,0x20,0x00,0x00,//t 84
  0x80,0x80,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x1F,0x20,0x20,0x20,0x10,0x3F,0x20,//u 85
  0x80,0x80,0x80,0x00,0x00,0x80,0x80,0x80,0x00,0x01,0x0E,0x30,0x08,0x06,0x01,0x00,//v 86
  0x80,0x80,0x00,0x80,0x00,0x80,0x80,0x80,0x0F,0x30,0x0C,0x03,0x0C,0x30,0x0F,0x00,//w 87
  0x00,0x80,0x80,0x00,0x80,0x80,0x80,0x00,0x00,0x20,0x31,0x2E,0x0E,0x31,0x20,0x00,//x 88
  0x80,0x80,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x81,0x8E,0x70,0x18,0x06,0x01,0x00,//y 89
  0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x21,0x30,0x2C,0x22,0x21,0x30,0x00,//z 90
  0x00,0x00,0x00,0x00,0x80,0x7C,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x3F,0x40,0x40,//{ 91
  0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,//| 92
  0x00,0x02,0x02,0x7C,0x80,0x00,0x00,0x00,0x00,0x40,0x40,0x3F,0x00,0x00,0x00,0x00,//} 93
  0x00,0x06,0x01,0x01,0x02,0x02,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,//~ 94
};
unsigned char code Hzk[]={
/*--  :  ͼ  --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x00,0xFE,0x02,0x42,0x22,0x32,0x5E,0x92,0x52,0x32,0x12,0x02,0x02,0xFE,0x00,0x00,
0x00,0xFF,0x42,0x42,0x42,0x51,0x55,0x64,0x69,0x41,0x42,0x42,0x42,0xFF,0x00,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x80,0x82,0x82,0xFE,0x82,0x82,0xFE,0x82,0x82,0x80,0x20,0x10,0x08,0x86,0x60,0x00,
0x80,0x40,0x30,0x0F,0x00,0x00,0xFF,0x00,0x00,0x80,0x84,0x42,0x21,0x10,0x0C,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x00,0x00,0x00,0xFE,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xFE,0x00,0x00,0x00,0x00,
0x40,0x42,0x44,0x58,0x40,0x7F,0x40,0x40,0x40,0x7F,0x40,0x50,0x48,0x46,0x40,0x00,

/*--  :  ʾ  --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x40,0x40,0x42,0x42,0x42,0x42,0x42,0xC2,0x42,0x42,0x42,0x42,0x42,0x40,0x40,0x00,
0x20,0x10,0x08,0x06,0x00,0x40,0x80,0x7F,0x00,0x00,0x00,0x02,0x04,0x08,0x30,0x00,

/*--  :  ģ  --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x10,0x10,0xD0,0xFF,0x90,0x14,0xE4,0xAF,0xA4,0xA4,0xA4,0xAF,0xE4,0x04,0x00,0x00,
0x04,0x03,0x00,0xFF,0x00,0x89,0x4B,0x2A,0x1A,0x0E,0x1A,0x2A,0x4B,0x88,0x80,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x20,0x30,0xAC,0x63,0x30,0x00,0x00,0xFE,0x22,0x22,0x22,0x22,0xFE,0x00,0x00,0x00,
0x22,0x67,0x22,0x12,0x12,0x40,0x40,0x7F,0x42,0x42,0x42,0x42,0x7F,0x40,0x40,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x10,0x60,0x02,0x8C,0x00,0xFE,0x02,0xF2,0x02,0xFE,0x00,0xF8,0x00,0xFF,0x00,0x00,
0x04,0x04,0x7E,0x01,0x80,0x47,0x30,0x0F,0x10,0x27,0x00,0x47,0x80,0x7F,0x00,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x40,0x40,0x42,0xCC,0x00,0x90,0x90,0x90,0x90,0x90,0xFF,0x10,0x11,0x16,0x10,0x00,
0x00,0x00,0x00,0x3F,0x10,0x28,0x60,0x3F,0x10,0x10,0x01,0x0E,0x30,0x40,0xF0,0x00,

};


unsigned char code pic1[]=
{/*--  128x160  --*/
0xFF,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x21,0xE1,0xF1,0x31,0x11,0x19,
0x19,0x19,0x11,0x31,0x19,0x0D,0x85,0x8F,0xCD,0xCD,0xDD,0xFD,0x71,0x41,0xC1,0xF1,
0xF9,0xF9,0xF9,0xF9,0xF1,0xF1,0xF1,0xF1,0xF1,0xF1,0x01,0x01,0x01,0x01,0x01,0x01,
0x01,0x01,0x01,0x01,0x01,0xC1,0xF9,0xFD,0xFF,0xFF,0xE1,0x01,0x01,0x01,0x01,0x01,
0x01,0x01,0x81,0xE1,0xF1,0xF9,0xFD,0xFD,0xFF,0xFF,0xFD,0xF9,0xF1,0xF1,0x59,0x09,
0x0D,0x0F,0x0F,0x07,0x05,0x0D,0x0D,0x0D,0x05,0x05,0x1D,0xFD,0xED,0xC1,0x81,0x01,
0x81,0x81,0xC1,0xC1,0xC1,0xC1,0x81,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0xF9,0xFF,
0xFF,0xE0,0xF8,0xF8,0xF8,0xF8,0xF8,0xF0,0xF0,0x78,0x1C,0x3F,0x3F,0xBE,0xBF,0xFF,
0xDF,0xDD,0x8F,0x87,0x03,0x03,0x07,0x87,0xEF,0xEF,0x7F,0x7F,0xF7,0xF2,0xF3,0xE7,
0xEF,0xDF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x38,0x10,0x00,0x00,
0x30,0x30,0x38,0x3C,0x3F,0x3D,0x37,0x26,0x3D,0x39,0x7F,0xF8,0x80,0x00,0x00,0x00,
0x00,0x00,0x03,0x0F,0x9F,0x7F,0x1F,0x0F,0x7F,0x7F,0xFF,0xFF,0xFB,0xFB,0xFB,0xF6,
0xEE,0x7C,0x18,0x18,0x78,0xFC,0xFC,0xFC,0xFC,0xF4,0xF6,0xF7,0xFD,0xFD,0xF9,0x07,
0x1F,0x3F,0xFF,0xFF,0xFF,0xFF,0x7F,0x1E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xC0,0x40,0xE0,0xF0,0x3C,0x1E,0x9B,0xFF,
0xFF,0x07,0x0F,0x1F,0x1F,0x1F,0xFF,0xFF,0x01,0x00,0xF8,0xFE,0xFF,0xFF,0x0F,0x03,
0x73,0x11,0x11,0xB3,0x0F,0x00,0x00,0x0F,0x03,0x18,0x04,0x0C,0xC8,0xC0,0xE3,0xFF,
0xFF,0xFF,0x7F,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x03,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC0,0x61,0x3F,0x7C,0xE8,0xC8,
0xC8,0xF8,0x3C,0xEF,0xF1,0xF8,0xFC,0xFC,0xFE,0xDE,0x6F,0x2F,0xFF,0xFF,0x3D,0x00,
0x00,0x00,0x00,0xE0,0xF8,0xF8,0xBD,0x3D,0xFD,0xFB,0xFB,0xF1,0xF1,0xE1,0x00,0x00,
0x00,0x00,0xFF,0x7C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xF0,0xFC,0x06,0x03,0x61,0xC0,0x00,0x03,0x07,0x04,0x9A,0x1B,0xFF,
0xFF,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0x00,0x00,0x07,0x0F,0x0F,0x0F,0x0F,0x0E,
0x0E,0x06,0x03,0x01,0x30,0x32,0x33,0x1F,0x1B,0x10,0x10,0x1C,0x0C,0x00,0x00,0x00,
0x00,0x00,0x00,0x80,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x0E,0x1C,0x18,0x11,0x3B,
0x7F,0xFF,0x60,0xC3,0x87,0x0F,0x0F,0x0F,0x0F,0x8E,0x86,0x8F,0x9C,0x8C,0x80,0x80,
0x00,0x00,0x00,0x01,0x0C,0x0C,0x1D,0x1C,0x3F,0x3F,0x3F,0x1F,0x1F,0x0F,0x01,0x00,
0xC0,0xE0,0x7F,0x1F,0x00,0x00,0x00,0x00,0x00,0xC0,0xE0,0xF0,0xF8,0xFC,0xFE,0xFC,
0xF8,0xE0,0xE0,0xE1,0xC7,0xDC,0xB0,0xE0,0x80,0x01,0x03,0x03,0x01,0x01,0x07,0xFF,
0xFF,0x00,0x00,0x00,0x00,0x00,0x03,0x0F,0x1C,0x38,0x30,0x20,0x60,0x60,0x40,0x40,
0xC0,0xC0,0xC0,0xC0,0xC0,0xC0,0xC0,0xC0,0x40,0x40,0x00,0x00,0x20,0x20,0x10,0x18,
0x08,0x0C,0x1E,0x1F,0x3F,0x3F,0xFF,0xFF,0x7F,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x03,0x0F,0x3C,0xF1,0xC3,0x06,0xE4,0xFC,0x78,0x39,0x11,0x11,0x11,0x31,0x30,
0x30,0x20,0x20,0x20,0x30,0xF0,0xF0,0x70,0x30,0x70,0xF8,0xF8,0xFC,0xE6,0x06,0x03,
0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC0,0xF1,0xFF,0x7F,0xDF,0x87,0xC3,0x7E,
0x9E,0xE1,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0xFE,0xFC,0xF8,0xFF,
0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF0,0xFC,
0xFE,0xFF,0xFF,0xFF,0xFF,0x63,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0xFC,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xFB,0x3F,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x07,0x07,0x0C,0x38,0xE0,0x40,0x01,0x03,0x0F,0x38,0xF0,
0x40,0x00,0x00,0x00,0x00,0x00,0x07,0x07,0x0F,0x1F,0x3F,0x3F,0x7E,0x7E,0x7E,0xFF,
0xFF,0xE3,0xC9,0x88,0x9A,0xB1,0xC1,0xFF,0xFF,0xFF,0xFF,0xFF,0x7F,0x1F,0x1F,0xFF,
0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,
0x07,0xEF,0xFF,0x0F,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x7C,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xFF,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC3,0xFE,0x3E,0x1C,0x0C,0x06,0x03,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x07,0xFF,0xC3,0x03,0x43,0xC7,0x87,0x87,0x87,0x03,0x01,0x00,0x00,0x00,0xFF,
0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x80,0xBF,0xE1,0xC0,0x80,0x80,0x80,0x80,0x80,0x80,0xE4,0xBC,0x88,0x88,0xF8,0xC8,
0x80,0x80,0x80,0x80,0x80,0xC0,0xC0,0xF8,0xCF,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x01,0x1F,0x38,0x60,0x40,0x40,0x42,0x42,0x46,0x66,0x7E,
0x46,0x40,0x40,0x00,0x00,0x40,0x40,0x60,0x7C,0x1F,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x01,0x0F,0x1C,0x18,0x38,0x30,0x31,0x3F,0x30,0x30,0x20,0x20,0x20,0xFF,
0xFF,0xE0,0xE0,0x00,0xE0,0xE0,0xE0,0x00,0xE0,0xE0,0xE0,0xE0,0x00,0xE0,0xE0,0xE0,
0x00,0xE0,0xE0,0xE0,0xE0,0x00,0xE0,0xE0,0xE0,0x00,0xE0,0xE0,0x00,0x00,0x00,0x00,
0xFC,0xFC,0x60,0x60,0xE0,0xC0,0x00,0x00,0xE0,0xE0,0x00,0x00,0xE0,0xE0,0x00,0x60,
0xE0,0x80,0x00,0x80,0xE0,0x60,0x00,0xC0,0xE0,0x60,0x40,0xFC,0xFC,0x00,0x00,0xEC,
0xEC,0x00,0x00,0xC0,0xE0,0x60,0x60,0xC0,0x00,0x00,0xE0,0xE0,0x40,0x60,0xE0,0xC0,
0x00,0x00,0xFC,0xFC,0x00,0xC0,0xE0,0x60,0x60,0xE0,0xC0,0x00,0x60,0xE0,0x80,0x00,
0x80,0xE0,0x60,0x00,0x00,0x00,0x00,0x80,0xE0,0x60,0xE0,0xC0,0x00,0x00,0x80,0xE0,
0x60,0x60,0xE0,0x80,0x00,0xE0,0xE0,0x60,0x60,0xE0,0xC0,0x40,0x60,0xE0,0xC0,0xFF,
0xFF,0x01,0x1F,0x1C,0x1F,0x00,0x1F,0x1C,0x1F,0x01,0x01,0x1F,0x1C,0x1F,0x00,0x1F,
0x1C,0x1F,0x01,0x01,0x1F,0x1C,0x1F,0x00,0x1F,0x1C,0x1F,0x01,0x18,0x18,0x00,0x00,
0x1F,0x1F,0x08,0x18,0x1F,0x0F,0x00,0x00,0x0F,0x1F,0x18,0x08,0x1F,0x1F,0x00,0xC0,
0xC3,0xFF,0x78,0x1F,0x03,0x00,0x00,0x0F,0x1F,0x18,0x08,0x1F,0x1F,0x00,0x00,0x1F,
0x1F,0x00,0x00,0x0D,0x19,0x1B,0x1F,0x0E,0x00,0x00,0xFF,0xFF,0x08,0x18,0x1F,0x0F,
0x00,0x00,0x1F,0x1F,0x00,0x0E,0x1E,0x1B,0x0B,0x1F,0x1F,0x00,0xC0,0xC3,0xFF,0x78,
0x1F,0x03,0x00,0x18,0x18,0x00,0x00,0x07,0x1F,0x18,0x1C,0x0C,0x00,0x00,0x07,0x1F,
0x18,0x18,0x1F,0x07,0x00,0x1F,0x1F,0x00,0x00,0x1F,0x1F,0x00,0x00,0x1F,0x1F,0xFF,
0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
0x00,0xF0,0xF8,0xFC,0xFC,0xFC,0xFC,0xFC,0xF8,0xF0,0xF0,0xC0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x40,0xE0,0x2C,0x1C,0x14,0x0C,0x08,0x08,0x0C,0x08,0x98,0x90,
0xE0,0xF8,0xFC,0xFC,0xFC,0xFC,0xFC,0xF8,0xF0,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0xF8,0xCC,
0xC6,0x86,0xC6,0xC6,0xC2,0xC2,0xC0,0xC2,0xC2,0xFE,0xFE,0xBE,0xFE,0xFE,0xFE,0xFE,
0xFC,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,
0xFF,0xE0,0xF0,0xE0,0xE0,0x38,0x18,0x0C,0x06,0x83,0xC3,0x61,0xB3,0xD7,0xFE,0xFC,
0xF8,0xF9,0xFF,0x07,0x07,0x07,0x0F,0x0F,0x0F,0x1F,0x3F,0x67,0xC0,0x80,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xE0,0x1C,0x33,0x7F,0x7F,0x7F,0xFF,0x7F,0x7F,0x3F,0x1F,0x01,0x01,0x00,
0x00,0x01,0x03,0x07,0x07,0x07,0x07,0x07,0x0F,0x19,0x30,0x60,0x80,0x00,0x00,0x00,
0x00,0x00,0xF0,0xF8,0xFC,0xFC,0xFC,0xFC,0xF8,0x7C,0x06,0x03,0x01,0x06,0x07,0x0D,
0x1E,0x9E,0xFE,0xFE,0xFF,0x7F,0x7F,0x4F,0xC7,0x81,0x03,0x03,0x03,0x03,0x3B,0xD9,
0xD9,0x9B,0x1E,0x3C,0xF0,0xE0,0x40,0xC0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,
0xFF,0x1F,0xFF,0xFF,0xDF,0xFE,0xFC,0xF8,0x7F,0x0F,0x16,0x1F,0x1F,0x1F,0x1F,0x1F,
0xFF,0x7F,0x3F,0x1E,0x1F,0x3F,0x7E,0xFE,0xFC,0xF8,0xF0,0xE0,0x00,0x01,0x03,0x06,
0x1C,0x30,0x60,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,
0xF0,0x1F,0x09,0xEE,0xE7,0x07,0x0F,0xFE,0xFC,0x70,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x07,0x0C,0x70,
0xC0,0x00,0x03,0x0F,0x0F,0x1F,0x1F,0x1F,0xFF,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x3F,0x7F,0xFF,0xFF,0xF0,0xE0,0xC0,0xC7,0xCF,0x7E,0x3C,0x00,0x00,0x00,0x10,
0x1B,0x1B,0x9A,0x04,0x07,0x03,0x00,0xC0,0x61,0x03,0x06,0xFC,0xF0,0x00,0x00,0xFF,
0xFF,0x00,0x00,0x01,0x03,0x0F,0xFF,0xFF,0x8E,0x0C,0x38,0xF0,0xE0,0x00,0x00,0x80,
0x01,0x07,0x0F,0x0E,0x00,0x30,0x30,0x3F,0x1F,0xDF,0x6F,0x27,0x00,0x00,0x00,0x00,
0x00,0x00,0xC0,0x79,0x1F,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0xF3,
0x80,0x60,0xC0,0x01,0x01,0x06,0x07,0x03,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xC7,0x7E,0x3C,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x7C,0xC0,0x00,0x00,0x00,0x00,
0x00,0x00,0x10,0x30,0x20,0x61,0x41,0x41,0x40,0x40,0x40,0x40,0x60,0x20,0x30,0x18,
0x0C,0x07,0x01,0x01,0x03,0x03,0x01,0x80,0xE0,0xB0,0xDC,0xC7,0xE1,0xE0,0xE0,0xFF,
0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0x67,0xCF,0x8E,0x0E,0x26,0x60,0x63,0x63,
0x30,0x18,0x18,0x18,0x08,0x08,0x04,0x06,0x03,0x00,0x00,0x00,0x00,0x30,0x70,0xF8,
0xFE,0xFF,0xFF,0xFF,0xFF,0xFE,0xFE,0xF8,0xF8,0xF0,0xE0,0x00,0x00,0x00,0x00,0x00,
0x01,0x03,0x06,0x05,0x0C,0x18,0x10,0x30,0x20,0xE0,0xC0,0x40,0xC0,0x00,0x00,0x80,
0xE0,0xF0,0xF0,0xF0,0xF0,0xE0,0xC0,0xE0,0xE0,0xE0,0xB0,0x10,0x08,0x0C,0x00,0x03,
0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x06,0x0C,0x0C,
0x08,0x18,0x18,0x10,0xF0,0xF0,0xF0,0xF0,0xE0,0xF0,0xF0,0xF0,0xF0,0xF0,0xF0,0xF8,
0xF8,0xF8,0xFC,0xFE,0xFE,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE1,0xFF,
0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x03,0x02,0x02,
0x02,0x02,0x82,0xC2,0xE2,0xFE,0xFE,0xFF,0xF1,0x00,0x00,0x00,0x00,0x00,0x00,0x01,
0x03,0x03,0x07,0x03,0x07,0x0F,0x1F,0x3F,0xE7,0xDF,0xEF,0x3E,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xE0,0xF0,0xF0,0xF0,0xF8,0xFC,0x07,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x03,0x0F,0x3F,0xFF,0xFF,0xFF,0xFF,0xFC,0xFB,0xFE,0xFF,0xFE,0xE0,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x07,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x7F,
0x3F,0x1F,0x1F,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xC1,0xB1,0x9A,0x88,0xC9,0xE3,0xFF,
0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x02,0x1F,0x3F,0x3F,0x3F,0x3F,0x3F,0x3F,0x03,0x1F,0x78,0xC0,0x80,0x00,0xC0,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE1,0x7F,0x00,0x81,0xFE,0xFE,0x00,0x00,
0x00,0x00,0x00,0x01,0x03,0x07,0x07,0x07,0xFF,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x07,0x1F,0x9F,0x9F,0x7F,0xFF,0x3F,0x1F,0x0F,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x07,0x07,0x07,0x7F,0xF3,0x01,0x01,0x00,0x00,
0x00,0x00,0x00,0x00,0x01,0x03,0x87,0x87,0x87,0xC7,0x43,0x03,0xC3,0xFF,0x07,0xFF,
0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x1F,0x30,0x60,
0xC0,0xC0,0x80,0x80,0x80,0xC0,0xE0,0x7E,0x03,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x31,0x60,0x40,0xC0,0x80,0x80,0x80,0xC0,
0x70,0x30,0x30,0x78,0xD8,0xCC,0xC6,0xC3,0x60,0x30,0x19,0x4F,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x1E,0x30,0x20,0x20,
0x20,0x20,0x20,0x20,0x30,0x30,0x3F,0x31,0x30,0x38,0x18,0x1C,0x0F,0x01,0x00,0xFF,
0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xF8,0xF8,0x98,0x98,0x98,0x98,0x00,0x00,0xF8,0xF8,
0x98,0x98,0x98,0xF8,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0xC0,0xF0,0x38,0x18,0x18,
0x38,0xF0,0xE0,0x00,0x00,0xF8,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,0xF8,0xF8,0x98,
0x98,0x98,0x98,0x00,0x00,0xF8,0xF8,0x18,0x18,0x38,0xF0,0xE0,0x00,0x00,0xC0,0x60,
0xF8,0xF8,0x00,0x00,0x00,0x00,0x00,0xF0,0xF8,0x18,0x18,0xF0,0xE0,0x00,0x60,0x70,
0x18,0x18,0xF8,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0xC0,0x60,0xF8,0xF8,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,
0xFF,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
0x80,0x80,0x80,0x80,0x80,0x80,0xBF,0xBF,0xB1,0xB1,0xB1,0xB1,0x80,0x80,0xBF,0xBF,
0x81,0x83,0x87,0x9D,0xB8,0xA0,0x86,0x86,0x86,0x86,0x80,0x87,0x9F,0xB8,0xB0,0xB0,
0xB8,0x9F,0x87,0x80,0x80,0xBF,0xBF,0xB0,0xB0,0xB0,0xB0,0x80,0x80,0xBF,0xBF,0xB1,
0xB1,0xB1,0xB1,0x80,0x80,0xBF,0xBF,0xB0,0xB0,0xB8,0x9F,0x8F,0x80,0x80,0x80,0x80,
0xBF,0xBF,0x80,0x80,0xB0,0xB0,0x80,0x99,0xBB,0xB3,0xB3,0x9F,0x8F,0x80,0xB0,0xBC,
0xBE,0xB7,0xB3,0xB0,0x80,0x86,0x86,0x86,0x86,0x80,0x80,0x80,0xBF,0xBF,0x80,0x80,
0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xFF,

};




void Delay(uint n)
{while(n--);
   
	return;
}


void delay_ms(uint Delay)
{unsigned int i; 
while(Delay)
  {
   for(;Delay>0;Delay--) 
   {  
    for(i=0;i<124;i++) 
        {;}   
    if((key_add==0)||(key_dec==0)) adj_Contrast();	     			
   }
  
	for(;log==1;);
  }

	return;
}




void Step(void) interrupt 0 using 0
{
	Delay(300);
	if(pause==0)log=!log;
   while(!pause);
  return;

}



void display_Contrast(uchar number)
{	uchar number1,number2;	uchar value[10] = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9'};
	number1=number/10;number2=number%10;
	ShowChar(0,0,value[number1]) ;
	ShowChar(6,0,value[number2]) ;

}



void adj_Contrast(void)
{	Delay(300);
 	 if((key_add==0)||(key_dec==0))
		{		
		 if	(key_add==0) 
			{
			Contrast+=1;if(Contrast>255)(Contrast=0);
		   	Set_Contrast_Control_Register(Contrast);	
			display_Contrast(Contrast);
			Delay(18000);
			if(key_add==0)
				{Delay(18000);
					if(key_add==0)			
						{Delay(18000);
							if(key_add==0)
								{Delay(18000);
									if(key_add==0)

										{while(key_add==0)
											{
											Contrast+=1; if(Contrast>255)(Contrast=0);
		   										Set_Contrast_Control_Register(Contrast);	
												display_Contrast(Contrast);
							 					Delay(20000); 
											}
										}
								}				
						}						
				}												
			}
	


		  
	
		 if	(key_dec==0) 
			{
			Contrast-=1; if(Contrast<0)(Contrast=255);
		   	Set_Contrast_Control_Register(Contrast);	
			display_Contrast(Contrast);
			Delay(18000);
			if(key_dec==0)
				{Delay(18000);
					if(key_dec==0)			
						{Delay(18000);
							if(key_dec==0)
								{Delay(18000);
									if(key_dec==0)

										{while(key_dec==0)
											{
											Contrast-=1; if(Contrast<0)(Contrast=255);
		   										Set_Contrast_Control_Register(Contrast);	
												display_Contrast(Contrast);
							 					Delay(20000); 
											}
										}
								}				
						}						
				}												
			}

	  	}
}






void Start(void)
{	SDA=1;
	SCL=1;
    _nop_();
	SDA=0;
    _nop_();
	SCL=0;
}	


void Stop(void)
{
	SCL=0;
	SDA=0;
    _nop_();
	SCL=1;
    _nop_();
	SDA=1;
}	


void Check_Ack(void)//Acknowledge
{
    unsigned char ack=1;
	SDA=1;
    SCL=1;
    _nop_();
    while(ack==1){ack=SDA;}
    _nop_();
    SCL=0;
    return;
}


void SentByte(unsigned char Byte)
{
	uchar i;
	for(i=0;i<8;i++)
     {  SCL=0;
        if((Byte&0x80)==0x80) SDA=1;
       	else SDA=0;
       	SCL=1;
    	_nop_();		
        Byte=Byte<<1;
     }
	SCL=0;

	
}

unsigned char ReceiveByte(void)
{uchar i,rudata=0;
	SCL=0;
	SDA=1;
	for(i=0;i<8;i++)
     {  SCL=1;
    	_nop_();	
		if (SDA==1)rudata|=0x01;
		else rudata|=0x00;
        rudata=rudata<<1;
		SCL=0;
    	_nop_();	
     }	
	Send_ACK();
	return rudata;
}

void Send_ACK(void)
{	SCL=0;
	SDA=0;
    _nop_();	
	SCL=1;
	SCL=0;
}


 
void Write_Data(unsigned char dat)
{
	Start();
	SentByte(Write_Address);
 	Check_Ack();
	SentByte(0x40);
 	Check_Ack();
 	SentByte(dat);
 	Check_Ack();
	Stop();
}


void Write_Instruction(unsigned char cmd)
{
	Start();
	SentByte(Write_Address);
 	Check_Ack();
	SentByte(0x00);
 	Check_Ack();
 	SentByte(cmd);
 	Check_Ack();
	Stop();
}



void Initial(void)
{
	RST=1;
	Delay(2000);
	RST=0;
	Delay(2000);
	RST=1;
	Delay(30000);

 	Write_Instruction(0xae);//Display OFF(sleep mode)
 	Write_Instruction(0x81);//Set Contrast Control
 	Write_Instruction(Contrast);
 	Write_Instruction(0xa0);//Set Segment Re-map
 	Write_Instruction(0xa4);//Set Entire Display OFF/ON
 	Write_Instruction(0xa6);//Set Normal/Reverse Display
 	Write_Instruction(0xa9);//Display Resolution Control
 	Write_Instruction(0x02);
 	Write_Instruction(0xad);//DC-DC Control Mode Set
 	Write_Instruction(0x80);
 	Write_Instruction(0xc0);//Set COM Output Scan Direction
 	Write_Instruction(0xd5);//Set Display Clock Divide Ratio/Oscillator Frequency
 	Write_Instruction(0x40);
 	Write_Instruction(0xd9);//Dis-charge/Pre-charge Period Mode Set
 	Write_Instruction(0x2f);
 	Write_Instruction(0xdb);//Set VCOMH Deselect Level
 	Write_Instruction(0x3f);
 	Write_Instruction(0x20);//Page addressing mode
 	Write_Instruction(0xdc);//VSEGM Deselect Level Mode Set
 	Write_Instruction(0x35);
 	Write_Instruction(0x30);//Set Discharge VSL Level
 	Write_Instruction(0xaf);//Set Display ON


}



void Set_Contrast_Control_Register(unsigned char mod)
{
    Write_Instruction(0x81);
	Write_Instruction(mod);
	return;
}


// Set page address 0~15
void Set_Page_Address(unsigned char add)
{
    Write_Instruction(0xb0);
    Write_Instruction(add);
	return;
}

void Set_Column_Address(unsigned char add)
{ 	  add=add+16;
    Write_Instruction((0x10|(add>>4)));
	Write_Instruction((0x0f&add));
	return;
}



void Set_Pos(unsigned char x, unsigned char y) 
{ 
 	  x=x+16;
	Write_Instruction(0xb0);
	Write_Instruction(y);
	Write_Instruction(((x&0xf0)>>4)|0x10);
	Write_Instruction((x&0x0f)); 
} 


				 
// ShowChar   size: 16/8 
void ShowChar(unsigned char x,unsigned char y,unsigned char chr)
{      	
	unsigned char c=0,i=0;	
		c=chr-' ';			
		if(x>Max_Column-1){x=0;if(SIZE==16)y+=2;else y+=1;}
		if(SIZE ==16)
			{
			Set_Pos(x,y);	
			for(i=0;i<8;i++)
			Write_Data(F8X16[c*16+i]);
			Set_Pos(x,y+1);
			for(i=0;i<8;i++)
			Write_Data(F8X16[c*16+i+8]);
			}
			else {	
				Set_Pos(x,y);
				for(i=0;i<6;i++)
				Write_Data(F6x8[c][i]);
				
			}
}



//m^n
unsigned int pow(unsigned char m,unsigned char n)
{
	unsigned int result=1;	 
	while(n--)result*=m;    
	return result;
}				  
//Show  number	 		  
void ShowNum(unsigned char x,unsigned char y,unsigned int num,unsigned char len,unsigned char size2)
{         	
	unsigned char t,temp;
	unsigned char enshow=0;						   
	for(t=0;t<len;t++)
	{
		temp=(num/pow(10,len-t-1))%10;
		if(enshow==0&&t<(len-1))
		{
			if(temp==0)
			{
				ShowChar(x+(size2/2)*t,y,' ');
				continue;
			}else enshow=1; 
		 	 
		}
	 	ShowChar(x+(size2/2)*t,y,temp+'0'); 
	}
} 
//ShowString
void ShowString(unsigned char x,unsigned char y,unsigned char *chr)
{
	unsigned char j=0;
	while (chr[j]!='\0')
	{		ShowChar(x,y,chr[j]);
			x+=8;
		if(x>120){x=0; if(SIZE==16)y+=2;else y+=1;}
			j++;
	}
}
//ShowCHinese
void ShowCHinese(unsigned char x,unsigned char y,unsigned char no)
{      			    
	unsigned char t;
	Set_Pos(x,y);	
    for(t=0;t<16;t++)
		{
				Write_Data(Hzk[32*no+t]);
			
        }	
		Set_Pos(x,y+1);	
    for(t=16;t<32;t++)
		{	
				Write_Data(Hzk[32*no+t]);
			
        }					
}

void DrawBMP(unsigned char x0, unsigned char y0,unsigned char x1, unsigned char y1,unsigned char BMP[])
{ 	
 unsigned int j=0;
 unsigned char x,y;
  
  if(y1%8==0) y=y1/8;      
  else y=y1/8+1;
	for(y=y0;y<y1;y++)
	{
		Set_Pos(x0,y);
    for(x=x0;x<x1;x++)
	    {      
	    	Write_Data(BMP[j++]);	    	
	    }
	}
} 



void ClearScreen(void)
{
    unsigned char i,j;
	for(i=0;i<20;i++)
	{
	Set_Page_Address(i);
    Set_Column_Address(0x00);
        for(j=0;j<128;j++)
		{
		    Write_Data(0x00);
		}
	}
    return;
}

void Show(unsigned char d1,unsigned char d2)
{
    unsigned char i,j;
	for(i=0;i<20;i++)
	{
	Set_Page_Address(i);
    Set_Column_Address(0x00);
        for(j=0;j<64;j++)
		{
		    Write_Data(d1);
			Write_Data(d2);
		}
	}
    return;
}


void Show_line_dot()
{
   Show(0x55,0xaa);
 	delay_ms(1000);
   Show(0xaa,0x55);
 	delay_ms(1000);

   Show(0x55,0x55);
 	delay_ms(1000);
   Show(0xaa,0xaa);
 	delay_ms(1000);

   Show(0xff,0x00);
 	delay_ms(1000);
   Show(0x00,0xff);
 	delay_ms(1000);

    return;
}



void main(void)
{   
	P0=0xff; P1=0xff;P2=0xff;P3=0xff;

	IE=0x81;
	IP=0x01;
	TCON=0x01;

	delay_ms(100);
    Initial();

	while(1)
	{
		 	ClearScreen();
	
	
	
		ShowCHinese(8,0,0);
		ShowCHinese(24,0,1);
		ShowCHinese(40,0,2);
		ShowCHinese(56,0,3);
		ShowCHinese(8,2,4);
		ShowCHinese(24,2,5);  
		ShowCHinese(40,2,6); 
 		ShowCHinese(56,2,7); 	 

		SIZE=16;
		ShowString(4,4,"Buydisplay.com");
		SIZE=8;
	 	ShowString(0,7,"2021/12/30");  
  		SIZE=8;
 	 	ShowString(0,9,"Hollw!EASTRISING!"); 
		delay_ms(1000);


		Show_line_dot();
	
	   	ClearScreen();

		DrawBMP(0,0,128,20,pic1); //x:0,y:0,col:128,line:8*8=64 	 
		delay_ms(1000);
	    Write_Instruction(0xa7);  //Set  inverse  display 	 
		delay_ms(1000);
	    Write_Instruction(0xa6);  //Set normal display 



 

	}
}








